"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VideoSection = void 0;

var _preact = require("preact");

var _ = require("../");

var _section = _interopRequireDefault(require("./section"));

var _userMediaState = require("../utils/user-media-state");

var _userMedia = require("../utils/user-media");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const resolutionOptions = [['640x480'], ['800x600'], ['1280x800'], ['1280×1024'], ['1920x1080'], ['1920x1200']];

class VideoSection extends _preact.Component {
  constructor(props) {
    super(props);

    this.onStateChange = () => {
      this.setState({
        mediaState: this.userMediaState.state,
        errorMessage: this.userMediaState.errorMessage
      });
    };

    this.onDevicesChange = () => {
      this.setState({
        devices: this.userMediaState.devices
      });
    };

    this.setVideoRef = dom => this.videoRef = dom;

    this.state = {
      mediaState: null,
      devices: [],
      recordingState: 'idle',
      fileName: '',
      hasStream: false,
      streamDetails: null,
      selectedResolution: '800x600',
      width: 800,
      height: 600
    };
  }

  recordSteam() {
    const mediaStream = this.userMediaState.mediaStream;

    if (mediaStream) {
      return (0, _userMedia.recordMediaStreamToFile)({
        stream: mediaStream,
        milliseconds: 10000,
        fileName: "".concat(this.state.fileName || 'video', ".webm")
      });
    }
  }

  componentDidMount() {
    this.userMediaState = new _userMediaState.UserMediaState();
    this.userMediaState.addEventListener('statechange', this.onStateChange);
    this.userMediaState.addEventListener('devicesChange', this.onDevicesChange);
    this.userMediaState.addEventListener('stream', ({
      detail
    }) => {
      const {
        stream
      } = detail,
            rest = _objectWithoutProperties(detail, ["stream"]);

      this.videoRef.srcObject = stream;
      this.setState({
        hasStream: true,
        streamDetails: rest
      });
    });
    this.userMediaState.addEventListener('streamLost', ({
      detail
    }) => {
      // eslint-disable-next-line no-console
      console.log('lost stream', detail);

      if (this.videoRef.srcObject === detail.stream) {
        this.videoRef.srcObject = null;
        this.setState({
          hasStream: false,
          streamDetails: null
        });
      }
    });
  }

  render() {
    let {
      mediaState,
      devices,
      hasStream,
      fileName,
      streamDetails,
      selectedResolution,
      errorMessage,
      width: stateWidth,
      height: stateHeight
    } = this.state;
    const hasDevices = devices.length > 0;
    let [width, height] = selectedResolution.split('x').map(Number);

    if (stateHeight && stateHeight !== height) {
      height = stateHeight;
    }

    if (stateWidth && stateWidth !== width) {
      width = stateWidth;
    }

    selectedResolution = "".concat(width, "x").concat(height);
    return (0, _preact.h)(_section.default, {
      title: "Video Utils"
    }, (0, _preact.h)("p", null, (0, _preact.h)("strong", null, "Current state:"), " ", mediaState, errorMessage && (0, _preact.h)("p", null, errorMessage), streamDetails && (0, _preact.h)("pre", {
      className: "f6"
    }, JSON.stringify(streamDetails, null, 2))), (0, _preact.h)("h3", null, "Target Resolutions"), (0, _preact.h)(_.Select, {
      value: selectedResolution,
      onChange: e => this.setState({
        selectedResolution: e.target.value,
        width: '',
        height: ''
      })
    }, resolutionOptions.map(value => (0, _preact.h)("option", {
      key: value,
      value: value
    }, value))), (0, _preact.h)("div", {
      className: "w5"
    }, (0, _preact.h)(_.InputField, {
      item: {
        name: 'width',
        label: 'Width',
        value: width,
        onInput: true
      },
      updateValue: value => this.setState({
        width: value
      })
    }), (0, _preact.h)(_.InputField, {
      item: {
        name: 'height',
        label: 'Height',
        value: height,
        onInput: true
      },
      updateValue: value => this.setState({
        height: value
      })
    })), hasStream && (0, _preact.h)("div", null, (0, _preact.h)("div", {
      className: "mw5"
    }, (0, _preact.h)(_.InputField, {
      item: {
        name: 'fileName',
        label: 'File Name',
        value: fileName,
        onInput: true
      },
      updateValue: value => this.setState({
        fileName: value
      })
    })), (0, _preact.h)(_.PromiseButton, {
      buttonText: "Record 10s",
      errorText: "Failed to record",
      successText: "Recorded!",
      loadingText: "Recording...",
      onClick: () => this.recordSteam(),
      resetTimeout: 2500
    })), (0, _preact.h)("h4", null, "Devices:"), (0, _preact.h)("div", {
      className: "flex flex-wrap gap2 mb2"
    }, devices.map(device => (0, _preact.h)(_.PromiseButton, {
      key: device.deviceId,
      pressed: device.selected,
      onClick: () => !device.selected && this.userMediaState.requestStream(device.deviceId, {
        height,
        width
      })
    }, device.label)), (0, _preact.h)(_.PromiseButton, {
      key: "refresh",
      buttonText: hasDevices ? 'Refresh list' : 'List Available Video Devices',
      errorText: "Failed to get devices",
      successText: "Refreshed devices!",
      loadingText: "Requesting...",
      onClick: () => hasDevices ? this.userMediaState.getDevices() : this.userMediaState.requestStream(null, {
        height,
        width
      }),
      resetTimeout: 2500
    })), (0, _preact.h)("video", {
      autoPlay: true,
      ref: this.setVideoRef,
      className: "mw6"
    }));
  }

}

exports.VideoSection = VideoSection;