"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getGqlFetch = void 0;

var _getStandardHeaders = require("./get-standard-headers");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const defaults = {
  getToken: () => null
};
/**
 * @param {{
 *   apiUrl: string
 *   getAppInfo?: () => {
 *     tabId: string
 *     appName: string
 *     appVersion: string
 *   }
 *   getToken: () => string
 *   handleNotAuthorized: () => any
 *   handleNoAuthentication: () => any
 * }} options
 * @returns {(query: string, variables?: any) => Promise}
 */

const getGqlFetch = options => (query, variables = null) => {
  const opts = Object.assign({}, defaults, options);
  const token = opts.getToken();
  const encodedQuery = encodeURIComponent(query.trim());
  const tokenQuery = token ? "&token=".concat(token) : '';

  const headers = _objectSpread(_objectSpread({}, variables ? {
    'content-type': 'application/json'
  } : null), opts.getAppInfo ? (0, _getStandardHeaders.getStandardHeaders)(opts.getAppInfo()) : null);

  return fetch("".concat(opts.apiUrl, "/graphql?query=").concat(encodedQuery).concat(tokenQuery), {
    method: 'post',
    body: variables ? JSON.stringify({
      variables
    }) : null,
    headers
  }).then(response => response.json()).then(parsed => {
    if (parsed.errors) {
      parsed.errors.forEach(error => {
        if (error.message === 'NO_AUTHENTICATION') {
          opts.handleNoAuthentication();
        }

        if (error.message === 'NOT_AUTHORIZED') {
          opts.handleNotAuthorized();
        }
      });
      throw parsed.errors;
    }

    return parsed;
  });
};

exports.getGqlFetch = getGqlFetch;