"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addDelay = exports.pause = void 0;

/**
 * @param {number} duration Time to delay in milliseconds
 * @param {any} [resolveValue] Optional value to resolve with
 * @returns {Promise<any>}
 */
const pause = (duration = 1000, resolveValue) => new Promise(resolve => {
  setTimeout(() => resolve(resolveValue), duration);
});
/**
 * Similar to pause, but can be used to add a delay to a promise chain and still
 * return the original value. If passing 0 for duration, it will return the
 * original value without the setTimeout.
 *
 * @param {number} duration Time to delay in milliseconds
 * @returns {(any) => Promise<any>}
 */


exports.pause = pause;

const addDelay = (duration = 1000) => val => duration ? pause(duration, val) : val;

exports.addDelay = addDelay;